pub struct ToolNode {
pub id: String,
pub python: String,
pub hermes_source: String,
pub lease: Value,
pub receipt_dir: String,
pub timeout_ms: u64,
pub ctx: RunContext,
}Expand description
A graph node that spawns the Hermes tools MCP broker as a child process and invokes tools through MCP JSON-RPC over stdio.
Fields
id: Stringpython: Stringhermes_source: Stringlease: Valuereceipt_dir: Stringtimeout_ms: u64ctx: RunContextTrait Implementations
Sourceimpl Node for ToolNode
impl Node for ToolNode
Sourcefn execute<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
state: &'life1 AgentState,
_: &'life2 GraphConfig,
) -> Pin<Box<dyn Future<Output = Result<NodeOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn execute<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
state: &'life1 AgentState,
_: &'life2 GraphConfig,
) -> Pin<Box<dyn Future<Output = Result<NodeOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Execute this node