pub struct OwnerLock {
pub path: PathBuf,
/* private fields */
}Expand description
A process-lifetime exclusive lock on a data directory.
The lock file is created at {data_dir}/.owner.lock with mode 0600.
The lock is held for the lifetime of this struct (RAII).
When dropped, the file handle is closed which automatically releases
the advisory lock.
Fields
path: PathBufImplementations