pub struct ApprovalGetParams {
pub approval_id: String,
}Fields
approval_id: StringTrait Implementations
Sourceimpl Debug for ApprovalGetParams
impl Debug for ApprovalGetParams
Sourceimpl<'de> Deserialize<'de> for ApprovalGetParams
impl<'de> Deserialize<'de> for ApprovalGetParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ApprovalGetParams
impl JsonSchema for ApprovalGetParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ApprovalGetParams
impl RefUnwindSafe for ApprovalGetParams
impl Send for ApprovalGetParams
impl Sync for ApprovalGetParams
impl Unpin for ApprovalGetParams
impl UnsafeUnpin for ApprovalGetParams
impl UnwindSafe for ApprovalGetParams