pub struct ApprovalListParams {
pub run_id: Option<String>,
pub status: Option<String>,
pub limit: Option<u32>,
}Fields
run_id: Option<String>status: Option<String>limit: Option<u32>Trait Implementations
Sourceimpl Debug for ApprovalListParams
impl Debug for ApprovalListParams
Sourceimpl<'de> Deserialize<'de> for ApprovalListParams
impl<'de> Deserialize<'de> for ApprovalListParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ApprovalListParams
impl JsonSchema for ApprovalListParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ApprovalListParams
impl RefUnwindSafe for ApprovalListParams
impl Send for ApprovalListParams
impl Sync for ApprovalListParams
impl Unpin for ApprovalListParams
impl UnsafeUnpin for ApprovalListParams
impl UnwindSafe for ApprovalListParams