pub struct PolicyCheckParams {
pub graph_id: String,
pub input: Option<Value>,
}Fields
graph_id: Stringinput: Option<Value>Trait Implementations
Sourceimpl Debug for PolicyCheckParams
impl Debug for PolicyCheckParams
Sourceimpl<'de> Deserialize<'de> for PolicyCheckParams
impl<'de> Deserialize<'de> for PolicyCheckParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PolicyCheckParams
impl JsonSchema for PolicyCheckParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PolicyCheckParams
impl RefUnwindSafe for PolicyCheckParams
impl Send for PolicyCheckParams
impl Sync for PolicyCheckParams
impl Unpin for PolicyCheckParams
impl UnsafeUnpin for PolicyCheckParams
impl UnwindSafe for PolicyCheckParams