pub struct RenderParams {
pub graph_id: String,
pub format: Option<String>,
}Fields
graph_id: Stringformat: Option<String>Trait Implementations
Sourceimpl Debug for RenderParams
impl Debug for RenderParams
Sourceimpl<'de> Deserialize<'de> for RenderParams
impl<'de> Deserialize<'de> for RenderParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RenderParams
impl JsonSchema for RenderParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RenderParams
impl RefUnwindSafe for RenderParams
impl Send for RenderParams
impl Sync for RenderParams
impl Unpin for RenderParams
impl UnsafeUnpin for RenderParams
impl UnwindSafe for RenderParams