pub struct RunCancelParams {
pub run_id: String,
pub reason: Option<String>,
}Fields
run_id: Stringreason: Option<String>Trait Implementations
Sourceimpl Debug for RunCancelParams
impl Debug for RunCancelParams
Sourceimpl<'de> Deserialize<'de> for RunCancelParams
impl<'de> Deserialize<'de> for RunCancelParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RunCancelParams
impl JsonSchema for RunCancelParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RunCancelParams
impl RefUnwindSafe for RunCancelParams
impl Send for RunCancelParams
impl Sync for RunCancelParams
impl Unpin for RunCancelParams
impl UnsafeUnpin for RunCancelParams
impl UnwindSafe for RunCancelParams