pub struct RunCheckpointParams {
pub run_id: Option<String>,
pub checkpoint_id: Option<String>,
}Fields
run_id: Option<String>checkpoint_id: Option<String>Trait Implementations
Sourceimpl Debug for RunCheckpointParams
impl Debug for RunCheckpointParams
Sourceimpl<'de> Deserialize<'de> for RunCheckpointParams
impl<'de> Deserialize<'de> for RunCheckpointParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RunCheckpointParams
impl JsonSchema for RunCheckpointParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RunCheckpointParams
impl RefUnwindSafe for RunCheckpointParams
impl Send for RunCheckpointParams
impl Sync for RunCheckpointParams
impl Unpin for RunCheckpointParams
impl UnsafeUnpin for RunCheckpointParams
impl UnwindSafe for RunCheckpointParams