pub struct RunEventsParams {
pub run_id: String,
pub cursor: Option<u64>,
pub limit: Option<u64>,
}Fields
run_id: Stringcursor: Option<u64>limit: Option<u64>Trait Implementations
Sourceimpl Debug for RunEventsParams
impl Debug for RunEventsParams
Sourceimpl<'de> Deserialize<'de> for RunEventsParams
impl<'de> Deserialize<'de> for RunEventsParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RunEventsParams
impl JsonSchema for RunEventsParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RunEventsParams
impl RefUnwindSafe for RunEventsParams
impl Send for RunEventsParams
impl Sync for RunEventsParams
impl Unpin for RunEventsParams
impl UnsafeUnpin for RunEventsParams
impl UnwindSafe for RunEventsParams