pub struct RunReceiptParams {
pub run_id: String,
}Fields
run_id: StringTrait Implementations
Sourceimpl Debug for RunReceiptParams
impl Debug for RunReceiptParams
Sourceimpl<'de> Deserialize<'de> for RunReceiptParams
impl<'de> Deserialize<'de> for RunReceiptParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RunReceiptParams
impl JsonSchema for RunReceiptParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RunReceiptParams
impl RefUnwindSafe for RunReceiptParams
impl Send for RunReceiptParams
impl Sync for RunReceiptParams
impl Unpin for RunReceiptParams
impl UnsafeUnpin for RunReceiptParams
impl UnwindSafe for RunReceiptParams