pub struct RunResumeParams {
pub checkpoint_id: Option<String>,
pub run_id: Option<String>,
}Fields
checkpoint_id: Option<String>run_id: Option<String>Trait Implementations
Sourceimpl Debug for RunResumeParams
impl Debug for RunResumeParams
Sourceimpl<'de> Deserialize<'de> for RunResumeParams
impl<'de> Deserialize<'de> for RunResumeParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RunResumeParams
impl JsonSchema for RunResumeParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RunResumeParams
impl RefUnwindSafe for RunResumeParams
impl Send for RunResumeParams
impl Sync for RunResumeParams
impl Unpin for RunResumeParams
impl UnsafeUnpin for RunResumeParams
impl UnwindSafe for RunResumeParams