pub struct RunStateParams {
pub run_id: String,
pub checkpoint_id: Option<String>,
pub json_pointer: Option<String>,
}Fields
run_id: Stringcheckpoint_id: Option<String>json_pointer: Option<String>Trait Implementations
Sourceimpl Debug for RunStateParams
impl Debug for RunStateParams
Sourceimpl<'de> Deserialize<'de> for RunStateParams
impl<'de> Deserialize<'de> for RunStateParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RunStateParams
impl JsonSchema for RunStateParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RunStateParams
impl RefUnwindSafe for RunStateParams
impl Send for RunStateParams
impl Sync for RunStateParams
impl Unpin for RunStateParams
impl UnsafeUnpin for RunStateParams
impl UnwindSafe for RunStateParams