pub struct RunWaitParams {
pub run_id: String,
pub timeout_ms: Option<u64>,
}Fields
run_id: Stringtimeout_ms: Option<u64>Trait Implementations
Sourceimpl Debug for RunWaitParams
impl Debug for RunWaitParams
Sourceimpl<'de> Deserialize<'de> for RunWaitParams
impl<'de> Deserialize<'de> for RunWaitParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RunWaitParams
impl JsonSchema for RunWaitParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RunWaitParams
impl RefUnwindSafe for RunWaitParams
impl Send for RunWaitParams
impl Sync for RunWaitParams
impl Unpin for RunWaitParams
impl UnsafeUnpin for RunWaitParams
impl UnwindSafe for RunWaitParams