pub struct TemplateListParams {
pub query: Option<String>,
}Fields
query: Option<String>Trait Implementations
Sourceimpl Debug for TemplateListParams
impl Debug for TemplateListParams
Sourceimpl<'de> Deserialize<'de> for TemplateListParams
impl<'de> Deserialize<'de> for TemplateListParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TemplateListParams
impl JsonSchema for TemplateListParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TemplateListParams
impl RefUnwindSafe for TemplateListParams
impl Send for TemplateListParams
impl Sync for TemplateListParams
impl Unpin for TemplateListParams
impl UnsafeUnpin for TemplateListParams
impl UnwindSafe for TemplateListParams