pub struct TemplateOutcomesParams {
pub template_id: String,
}Fields
template_id: StringTrait Implementations
Sourceimpl Debug for TemplateOutcomesParams
impl Debug for TemplateOutcomesParams
Sourceimpl<'de> Deserialize<'de> for TemplateOutcomesParams
impl<'de> Deserialize<'de> for TemplateOutcomesParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TemplateOutcomesParams
impl JsonSchema for TemplateOutcomesParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TemplateOutcomesParams
impl RefUnwindSafe for TemplateOutcomesParams
impl Send for TemplateOutcomesParams
impl Sync for TemplateOutcomesParams
impl Unpin for TemplateOutcomesParams
impl UnsafeUnpin for TemplateOutcomesParams
impl UnwindSafe for TemplateOutcomesParams