pub struct WitnessCaptureParams {
pub locator: String,
pub content: String,
pub media_type: String,
pub authority_class: String,
pub retrieved_at: Option<String>,
}Expand description
Caller-supplied local capture. This endpoint never dereferences the locator.
Fields
locator: Stringcontent: Stringmedia_type: Stringretrieved_at: Option<String>Trait Implementations
Sourceimpl Debug for WitnessCaptureParams
impl Debug for WitnessCaptureParams
Sourceimpl<'de> Deserialize<'de> for WitnessCaptureParams
impl<'de> Deserialize<'de> for WitnessCaptureParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WitnessCaptureParams
impl JsonSchema for WitnessCaptureParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WitnessCaptureParams
impl RefUnwindSafe for WitnessCaptureParams
impl Send for WitnessCaptureParams
impl Sync for WitnessCaptureParams
impl Unpin for WitnessCaptureParams
impl UnsafeUnpin for WitnessCaptureParams
impl UnwindSafe for WitnessCaptureParams