RunManager

Struct RunManager 

pub struct RunManager { /* private fields */ }

Implementations

Source

impl RunManager

pub fn allocate( &self, graph_id: &str, graph_version: &str, input: Value, ) -> Result<String, String>

pub fn allocate_with_budgets( &self, graph_id: &str, graph_version: &str, input: Value, budgets: Option<RunBudgets>, ) -> Result<String, String>

pub fn allocate_resumed( &self, run_id: &str, graph_id: &str, graph_version: &str, input: Value, state: Value, budgets: Option<RunBudgets>, checkpoint_id: &str, checkpoint_digest: &str, approval: Option<Value>, ) -> Result<String, String>

pub fn mark_checkpointed( &self, id: &str, checkpoint_id: &str, checkpoint_digest: &str, ) -> Result<(), String>

pub fn admit_async(&self, id: &str) -> Result<(), String>

Atomically reserves one of the bounded execution slots for an accepted run.

pub fn reserve_async_slot(&self) -> Result<(), String>

Reserve capacity before an irreversible durable transition. The caller must either activate or release this reservation.

pub fn release_async_slot(&self)

pub fn admit_reserved_async(&self, id: &str) -> Result<(), String>

pub fn execute( &self, run_id: &str, spec: GraphSpec, base_url: String, default_model: String, ) -> Result<Value, String>

pub fn execute_with_store( &self, run_id: &str, spec: GraphSpec, base_url: String, default_model: String, store: Option<PersistentStore>, ) -> Result<Value, String>

pub fn execute_with_store_options( &self, run_id: &str, spec: GraphSpec, base_url: String, default_model: String, store: Option<PersistentStore>, initial_state: Option<Value>, initial_counters: BudgetCounters, ) -> Result<Value, String>

pub fn start( &self, run_id: String, spec: GraphSpec, base_url: String, model: String, )

pub fn start_with_completion<F>( &self, run_id: String, spec: GraphSpec, base_url: String, model: String, on_completion: F, )
where F: FnOnce(RunRecord) + Send + 'static,

pub fn start_with_completion_with_store<F>( &self, run_id: String, spec: GraphSpec, base_url: String, model: String, store: Option<PersistentStore>, on_completion: F, )
where F: FnOnce(RunRecord) + Send + 'static,

pub fn start_resumed_with_completion<F>( &self, run_id: String, spec: GraphSpec, base_url: String, model: String, store: Option<PersistentStore>, on_completion: F, )
where F: FnOnce(RunRecord) + Send + 'static,

pub fn cancel(&self, id: &str) -> Result<Value, String>

pub fn get(&self, id: &str) -> Option<RunRecord>

pub fn mark_persistence(&self, id: &str, status: &str, error: Option<String>)

pub fn list(&self) -> Vec<Value>

pub fn events( &self, store: Option<&PersistentStore>, id: &str, cursor: u64, limit: usize, ) -> Result<Value, String>

pub fn set_state_value( &self, id: &str, key: &str, value: Value, ) -> Result<(), String>